pub struct CustomIncomingPaymentOptions {
pub description: Option<String>,
pub amount: Option<u64>,
pub unix_expiry: Option<u64>,
pub extra_json: Option<String>,
}Fields
description: Option<String>amount: Option<u64>unix_expiry: Option<u64>extra_json: Option<String>Extra payment-method-specific fields as JSON string These fields are flattened into the JSON representation on the client side
Implementations
Sourceimpl CustomIncomingPaymentOptions
impl CustomIncomingPaymentOptions
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn amount(&self) -> u64
pub fn amount(&self) -> u64
Returns the value of amount, or the default value if amount is unset.
Sourcepub fn unix_expiry(&self) -> u64
pub fn unix_expiry(&self) -> u64
Returns the value of unix_expiry, or the default value if unix_expiry is unset.
Sourcepub fn extra_json(&self) -> &str
pub fn extra_json(&self) -> &str
Returns the value of extra_json, or the default value if extra_json is unset.