pub struct OnchainFeeOption {
pub fee_reserve: u64,
pub estimated_blocks: u32,
pub fee_index: u32,
}Fields
fee_reserve: u64estimated_blocks: u32fee_index: u32Trait Implementations
Sourceimpl Clone for OnchainFeeOption
impl Clone for OnchainFeeOption
Sourcefn clone(&self) -> OnchainFeeOption
fn clone(&self) -> OnchainFeeOption
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OnchainFeeOption
impl Debug for OnchainFeeOption
Sourceimpl Default for OnchainFeeOption
impl Default for OnchainFeeOption
Sourceimpl From<MeltQuoteOnchainFeeOption> for OnchainFeeOption
impl From<MeltQuoteOnchainFeeOption> for OnchainFeeOption
Sourcefn from(value: MeltQuoteOnchainFeeOption) -> Self
fn from(value: MeltQuoteOnchainFeeOption) -> Self
Converts to this type from the input type.
Sourceimpl From<OnchainFeeOption> for MeltQuoteOnchainFeeOption
impl From<OnchainFeeOption> for MeltQuoteOnchainFeeOption
Sourcefn from(value: OnchainFeeOption) -> Self
fn from(value: OnchainFeeOption) -> Self
Converts to this type from the input type.
Sourceimpl Hash for OnchainFeeOption
impl Hash for OnchainFeeOption
Sourceimpl Message for OnchainFeeOption
impl Message for OnchainFeeOption
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for OnchainFeeOption
impl PartialEq for OnchainFeeOption
Sourcefn eq(&self, other: &OnchainFeeOption) -> bool
fn eq(&self, other: &OnchainFeeOption) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for OnchainFeeOption
impl Eq for OnchainFeeOption
impl StructuralPartialEq for OnchainFeeOption