pub struct PaymentEventResponse {
pub event: Option<Event>,
}Fields
event: Option<Event>Trait Implementations
Sourceimpl Clone for PaymentEventResponse
impl Clone for PaymentEventResponse
Sourcefn clone(&self) -> PaymentEventResponse
fn clone(&self) -> PaymentEventResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PaymentEventResponse
impl Debug for PaymentEventResponse
Sourceimpl Default for PaymentEventResponse
impl Default for PaymentEventResponse
Sourceimpl From<Event> for PaymentEventResponse
impl From<Event> for PaymentEventResponse
Sourceimpl Hash for PaymentEventResponse
impl Hash for PaymentEventResponse
Sourceimpl Message for PaymentEventResponse
impl Message for PaymentEventResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PaymentEventResponse
impl PartialEq for PaymentEventResponse
Sourcefn eq(&self, other: &PaymentEventResponse) -> bool
fn eq(&self, other: &PaymentEventResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<PaymentEventResponse> for Event
impl TryFrom<PaymentEventResponse> for Event
impl Eq for PaymentEventResponse
impl StructuralPartialEq for PaymentEventResponse