PaymentProcessorClient

Struct PaymentProcessorClient 

pub struct PaymentProcessorClient { /* private fields */ }
Payment Processor

Implementations

Source

impl PaymentProcessorClient

pub async fn new( addr: &str, port: u16, tls_dir: Option<PathBuf>, ) -> Result<Self>

Connect to a payment processor.

When tls_dir is provided, it must contain ca.pem, client.pem, and client.key. The CA certificate authenticates the server, while the client certificate and key authenticate this client to the server.