PaymentQuoteResponse

Struct PaymentQuoteResponse 

pub struct PaymentQuoteResponse {
    pub request_identifier: Option<PaymentIdentifier>,
    pub amount: u64,
    pub fee: u64,
    pub state: i32,
    pub unit: String,
    pub extra_json: Option<String>,
}

Fields

request_identifier: Option<PaymentIdentifier>amount: u64fee: u64state: i32unit: Stringextra_json: Option<String>

Extra payment-method-specific fields as JSON string For custom payment methods, these fields are flattened into the response

Implementations

Source

impl PaymentQuoteResponse

pub fn state(&self) -> QuoteState

Returns the enum value of state, or the default if the field is set to an invalid enum value.

pub fn set_state(&mut self, value: QuoteState)

Sets state to the provided enum value.

pub fn extra_json(&self) -> &str

Returns the value of extra_json, or the default value if extra_json is unset.