pub struct PaymentSuccessfulResponse {
pub quote_id: String,
pub details: Option<MakePaymentResponse>,
}Fields
quote_id: Stringdetails: Option<MakePaymentResponse>Trait Implementations
Sourceimpl Clone for PaymentSuccessfulResponse
impl Clone for PaymentSuccessfulResponse
Sourcefn clone(&self) -> PaymentSuccessfulResponse
fn clone(&self) -> PaymentSuccessfulResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PaymentSuccessfulResponse
impl Debug for PaymentSuccessfulResponse
Sourceimpl Default for PaymentSuccessfulResponse
impl Default for PaymentSuccessfulResponse
Sourceimpl Hash for PaymentSuccessfulResponse
impl Hash for PaymentSuccessfulResponse
Sourceimpl Message for PaymentSuccessfulResponse
impl Message for PaymentSuccessfulResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PaymentSuccessfulResponse
impl PartialEq for PaymentSuccessfulResponse
Sourcefn eq(&self, other: &PaymentSuccessfulResponse) -> bool
fn eq(&self, other: &PaymentSuccessfulResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for PaymentSuccessfulResponse
impl StructuralPartialEq for PaymentSuccessfulResponse